@@ -17,9 +17,9 @@ from easyshare.utils.types import to_int
 APP_NAME = "easyshare"
 APP_NAME_SERVER = "esd"
 APP_NAME_CLIENT = "es"
-APP_VERSION = "0.1"
+APP_VERSION = "0.4"
 
-APP_INFO = "{} {}".format(APP_NAME, APP_VERSION)
+APP_INFO = f"{APP_NAME} {APP_VERSION}"
 
 # =====================
 # ===== RESOURCES =====
@@ -108,6 +108,6 @@ def easyshare_setup():
                                 raise_exceptions=False,
                                 default=logging.VERBOSITY_NONE)
 
-    root_log = get_logger(logging.ROOT_LOGGER_NAME)
+    root_log = get_logger()
     root_log.set_verbosity(starting_verbosity)
     root_log.d("Starting with verbosity = %d", starting_verbosity)
