@@ -4,7 +4,7 @@ from typing import Callable, List, Optional
 from Pyro5.server import expose
 
 from easyshare.esd.common import ClientContext, Sharing
-from easyshare.esd.services import BaseClientSharingService, check_sharing_service_owner, FPath
+from easyshare.esd.services import BaseClientSharingService, check_sharing_service_owner_endpoint, FPath
 from easyshare.esd.services.transfer.get import GetService
 from easyshare.esd.services.transfer.put import PutService
 from easyshare.logging import get_logger
@@ -78,7 +78,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @ensure_d_sharing
     def rcd(self, spath: str) -> Response:
         spath = spath or "/"
@@ -119,7 +119,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @ensure_d_sharing
     def rpwd(self) -> Response:
         client_endpoint = pyro_client_endpoint()
@@ -135,7 +135,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @ensure_d_sharing
     def rls(self, *,
             path: str = None, sort_by: List[str] = None,
@@ -170,16 +170,20 @@ class SharingService(ISharingService, BaseClientSharingService):
             # OK - report it
             print(f"[{self.client.tag}] rls '{ls_fpath}'")
         except FileNotFoundError:
+            log.exception("rls exception occurred")
             return self._create_error_response(ServerErrors.NOT_EXISTS,
                                                ls_fpath)
         except PermissionError:
+            log.exception("rls exception occurred")
             return self._create_error_response(ServerErrors.PERMISSION_DENIED,
                                                ls_fpath)
         except OSError as oserr:
+            log.exception("rls exception occurred")
             return self._create_error_response(ServerErrors.ERR_2,
                                                os_error_str(oserr),
                                                ls_fpath)
         except Exception as exc:
+            log.exception("rls exception occurred")
             return self._create_error_response(ServerErrors.ERR_2,
                                                exc,
                                                ls_fpath)
@@ -192,7 +196,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @ensure_d_sharing
     def rtree(self, *, path: str = None, sort_by: List[str] = None,
               reverse: bool = False, hidden: bool = False,
@@ -228,16 +232,20 @@ class SharingService(ISharingService, BaseClientSharingService):
             # OK - report it
             print(f"[{self.client.tag}] rtree '{tree_fpath}'")
         except FileNotFoundError:
+            log.exception("rtree exception occurred")
             return self._create_error_response(ServerErrors.NOT_EXISTS,
                                                tree_fpath)
         except PermissionError:
+            log.exception("rtree exception occurred")
             return self._create_error_response(ServerErrors.PERMISSION_DENIED,
                                                tree_fpath)
         except OSError as oserr:
+            log.exception("rtree exception occurred")
             return self._create_error_response(ServerErrors.ERR_2,
                                                os_error_str(oserr),
                                                tree_fpath)
         except Exception as exc:
+            log.exception("rtree exception occurred")
             return self._create_error_response(ServerErrors.ERR_2,
                                                exc,
                                                tree_fpath)
@@ -251,7 +259,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @check_write_permission
     @ensure_d_sharing
     def rmkdir(self, directory: str) -> Response:
@@ -276,16 +284,20 @@ class SharingService(ISharingService, BaseClientSharingService):
             # OK - report it
             print(f"[{self.client.tag}] rmkdir '{directory_fpath}'")
         except PermissionError:
+            log.exception("rmkdir exception occurred")
             return self._create_error_response(ServerErrors.PERMISSION_DENIED,
                                                directory_fpath)
         except FileExistsError:
+            log.exception("rmkdir exception occurred")
             return self._create_error_response(ServerErrors.DIRECTORY_ALREADY_EXISTS,
                                                directory_fpath)
         except OSError as oserr:
+            log.exception("rmkdir exception occurred")
             return self._create_error_response(ServerErrors.ERR_2,
                                                os_error_str(oserr),
                                                directory_fpath)
         except Exception as exc:
+            log.exception("rmkdir exception occurred")
             return self._create_error_response(ServerErrors.ERR_2,
                                                exc,
                                                directory_fpath)
@@ -295,7 +307,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @check_write_permission
     @ensure_d_sharing
     def rcp(self, sources: List[str], destination: str) -> Response:
@@ -306,15 +318,19 @@ class SharingService(ISharingService, BaseClientSharingService):
 
         def handle_cp_exception(exc: Exception, src: FPath, dst: FPath):
             if isinstance(exc, PermissionError):
+                log.exception("rcp exception occurred")
                 errors.append(create_error_of_response(ServerErrors.CP_PERMISSION_DENIED,
                                                        *self._qspathify(src, dst)))
             elif isinstance(exc, FileNotFoundError):
+                log.exception("rcp exception occurred")
                 errors.append(create_error_of_response(ServerErrors.CP_NOT_EXISTS,
                                                        *self._qspathify(src, dst)))
             elif isinstance(exc, OSError):
+                log.exception("rcp exception occurred")
                 errors.append(create_error_of_response(ServerErrors.CP_OTHER_ERROR,
                                                        os_error_str(exc), *self._qspathify(src, dst)))
             else:
+                log.exception("rcp exception occurred")
                 errors.append(create_error_of_response(ServerErrors.CP_OTHER_ERROR,
                                                        exc, *self._qspathify(src, dst)))
 
@@ -332,7 +348,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @check_write_permission
     @ensure_d_sharing
     def rmv(self, sources: List[str], destination: str) -> Response:
@@ -343,15 +359,19 @@ class SharingService(ISharingService, BaseClientSharingService):
 
         def handle_mv_exception(exc: Exception, src: FPath, dst: FPath):
             if isinstance(exc, PermissionError):
+                log.exception("rmv exception occurred")
                 errors.append(create_error_of_response(ServerErrors.MV_PERMISSION_DENIED,
                                                        *self._qspathify(src, dst)))
             elif isinstance(exc, FileNotFoundError):
+                log.exception("rmv exception occurred")
                 errors.append(create_error_of_response(ServerErrors.MV_NOT_EXISTS,
                                                        *self._qspathify(src, dst)))
             elif isinstance(exc, OSError):
+                log.exception("rmv exception occurred")
                 errors.append(create_error_of_response(ServerErrors.MV_OTHER_ERROR,
                                                        os_error_str(exc), *self._qspathify(src, dst)))
             else:
+                log.exception("rmv exception occurred")
                 errors.append(create_error_of_response(ServerErrors.MV_OTHER_ERROR,
                                                        exc, *self._qspathify(src, dst)))
 
@@ -443,7 +463,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @check_write_permission
     @ensure_d_sharing
     def rrm(self, paths: List[str]) -> Response:
@@ -457,16 +477,20 @@ class SharingService(ISharingService, BaseClientSharingService):
         errors = []
         def handle_rm_error(exc: Exception, path: Path):
             if isinstance(exc, PermissionError):
+                log.exception("rrm exception occurred")
                 errors.append(create_error_of_response(ServerErrors.RM_PERMISSION_DENIED,
                                                        *self._qspathify(path)))
             elif isinstance(exc, FileNotFoundError):
+                log.exception("rrm exception occurred")
                 errors.append(create_error_of_response(ServerErrors.RM_NOT_EXISTS,
                                                        *self._qspathify(path)))
             elif isinstance(exc, OSError):
+                log.exception("rrm exception occurred")
                 errors.append(create_error_of_response(ServerErrors.RM_OTHER_ERROR,
                                                        os_error_str(exc),
                                                        *self._qspathify(path)))
             else:
+                log.exception("rrm exception occurred")
                 errors.append(create_error_of_response(ServerErrors.RM_OTHER_ERROR,
                                                        exc,
                                                        *self._qspathify(path)))
@@ -496,7 +520,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     # NO  @ensure_d_sharing, allowed for files too
     def get(self, paths: List[str], check: bool = False) -> Response:
         client_endpoint = pyro_client_endpoint()
@@ -529,7 +553,7 @@ class SharingService(ISharingService, BaseClientSharingService):
     @expose
     @trace_api
     @try_or_command_failed_response
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     @ensure_d_sharing # Allowed only for F sharings
     def put(self, check: bool = False) -> Response:
         client_endpoint = pyro_client_endpoint()
@@ -551,7 +575,7 @@ class SharingService(ISharingService, BaseClientSharingService):
 
     @expose
     @trace_api
-    @check_sharing_service_owner
+    @check_sharing_service_owner_endpoint
     # so bad that pyro calls the "close" object when a tracked resource is released
     # we have to call this close_
     def close_(self):
